@@ -412,6 +412,16 @@ class ListSerializer(ArgumentSerializer):
     return self.list_sep.join([_helpers.str_or_unicode(x) for x in value])
 
 
+class EnumClassListSerializer(ListSerializer):
+
+  def serialize(self, value):
+    """See base class."""
+    if isinstance(value, list):
+      return self.list_sep.join(_helpers.str_or_unicode(x.name) for x in value)
+    else:
+      return _helpers.str_or_unicode(value.name)
+
+
 class CsvListSerializer(ArgumentSerializer):
 
   def __init__(self, list_sep):
@@ -435,6 +445,14 @@ class CsvListSerializer(ArgumentSerializer):
     return _helpers.str_or_unicode(serialized_value)
 
 
+class EnumClassSerializer(ArgumentSerializer):
+  """Class for generating string representations of an enum class flag value."""
+
+  def serialize(self, value):
+    """Returns a serialized string of the Enum class value."""
+    return _helpers.str_or_unicode(value.name)
+
+
 class BaseListParser(ArgumentParser):
   """Base class for a parser of lists of strings.
 
